@@ -46,12 +46,47 @@ def tearDownTempProjects(thing):
     dxpy.set_workspace_id(thing.old_workspace_id)
 
 class TestDXProject(unittest.TestCase):
+    # Also test DXContainer here
     def setUp(self):
         setUpTempProjects(self)
 
     def tearDown(self):
         tearDownTempProjects(self)
 
+    def test_init_and_set_id(self):
+        for good_value in ["project-aB3456789012345678901234", None]:
+            dxproject = dxpy.DXProject(good_value)
+            dxproject.set_id(good_value)
+        for bad_value in ["foo",
+                          "container-123456789012345678901234",
+                          3,
+                          {},
+                          "project-aB34567890123456789012345",
+                          "project-aB345678901234567890123"]:
+            with self.assertRaises(DXError):
+                dxpy.DXProject(bad_value)
+            with self.assertRaises(DXError):
+                dxproject = dxpy.DXProject()
+                dxproject.set_id(bad_value)
+
+    def test_dxcontainer_init_and_set_id(self):
+        for good_value in ["container-aB3456789012345678901234"]:
+            # Note: None is actually not a valid value if the current
+            # project context is a project
+            dxcontainer = dxpy.DXContainer(good_value)
+            dxcontainer.set_id(good_value)
+        for bad_value in ["foo",
+                          "project-123456789012345678901234",
+                          3,
+                          {},
+                          "container-aB34567890123456789012345",
+                          "container-aB345678901234567890123"]:
+            with self.assertRaises(DXError):
+                dxpy.DXContainer(bad_value)
+            with self.assertRaises(DXError):
+                dxcontainer = dxpy.DXContainer()
+                dxcontainer.set_id(bad_value)
+
     def test_update_describe(self):
         dxproject = dxpy.DXProject()
         dxproject.update(name="newprojname", protected=True, restricted=True, description="new description")
@@ -192,6 +227,41 @@ class TestDXFile(unittest.TestCase):
 
         tearDownTempProjects(self)
 
+    def test_init_and_set_ids(self):
+        for good_dxid, good_project in [
+                ("file-aB3456789012345678901234", None),
+                (None, "project-aB3456789012345678901234"),
+                (None, "container-aB3456789012345678901234"),
+                (None, None),
+                ({"$dnanexus_link": {"id" : "file-aB3456789012345678901234"}}, None),
+                ({"$dnanexus_link": {"id" : "file-aB3456789012345678901234",
+                                     "project": "project-aB3456789012345678901234"}}, None),
+                ({"$dnanexus_link": {"id" : "file-aB3456789012345678901234",
+                                     "project": "container-aB3456789012345678901234"}}, None)
+        ]:
+            dxfile = dxpy.DXFile(good_dxid, project=good_project)
+            dxfile.set_ids(good_dxid, project=good_project)
+        for bad_dxid, bad_project in [
+                ("foo", None),
+                ("record-123456789012345678901234", None),
+                (3, None),
+                ({}, None),
+                ({"$dnanexus_link": {"id": "foo"}}, None),
+                ({"$dnanexus_link": {"id": "file-aB3456789012345678901234",
+                                     "project": "foo"}}, None)
+        ]:
+            with self.assertRaises(DXError):
+                dxpy.DXFile(bad_dxid, project=bad_project)
+            with self.assertRaises(DXError):
+                dxfile = dxpy.DXFile()
+                dxfile.set_ids(bad_dxid, project=bad_project)
+
+        # test logic
+        dxfile = dxpy.DXFile({"$dnanexus_link": {"id" : "file-aB3456789012345678901234",
+                                                 "project": "container-aB3456789012345678901234"}},
+                             project="project-aB3456789012345678901234")
+        self.assertEqual(dxfile.get_proj_id(), "project-aB3456789012345678901234")
+
     def test_upload_download_files_dxfile(self):
         self.dxfile = dxpy.upload_local_file(self.foo_file.name)
 
@@ -449,7 +519,7 @@ class TestDXGTable(unittest.TestCase):
 
         # Use open_dxgtable and leave table open
         table3_id = dxpy.new_dxgtable([dxpy.DXGTable.make_column_desc("a", "string"),
-                                       dxpy.DXGTable.make_column_desc("b", "int32")])
+                                       dxpy.DXGTable.make_column_desc("b", "int32")]).get_id()
         with self.assertRaises(DXAPIError):
             with dxpy.open_dxgtable(table3_id, mode='a') as table3:
                 table3.add_row(["", 68719476736]) # Not in int32 range
@@ -687,8 +757,7 @@ class TestDXRecord(unittest.TestCase):
             self.fail("Unexpected error when removing record object: " +
                       str(error))
 
-        with self.assertRaises(AttributeError):
-            firstDXRecord.get_id()
+        self.assertIsNone(firstDXRecord.get_id())
 
         try:
             secondDXRecord.remove()
@@ -696,8 +765,7 @@ class TestDXRecord(unittest.TestCase):
             self.fail("Unexpected error when removing record object: " +
                       str(error))
 
-        with self.assertRaises(AttributeError):
-            secondDXRecord.get_id()
+        self.assertIsNone(secondDXRecord.get_id())
 
         third_record = dxpy.DXRecord(firstID)
 
@@ -772,6 +840,17 @@ class TestDXRecord(unittest.TestCase):
         self.assertEqual(desc["properties"], properties)
         self.assertEqual(desc["details"], details)
 
+    def test_getattr_dxrecord(self):
+        dxrecord = dxpy.new_dxrecord(name='foo')
+        record_id = dxrecord.get_id()
+        self.assertEqual(dxrecord.name, 'foo')
+        with self.assertRaises(AttributeError):
+            dxrecord.foo
+        dxrecord.remove()
+        dxrecord.set_ids(record_id)
+        with self.assertRaises(DXAPIError):
+            dxrecord.name
+
     def test_set_properties_of_dxrecord(self):
         dxrecord = dxpy.new_dxrecord()
         properties = {"project": "cancer project", "foo": "bar"}
@@ -903,6 +982,24 @@ class TestDXAppletJob(unittest.TestCase):
     def tearDown(self):
         tearDownTempProjects(self)
 
+    def test_dxjob_init_and_set_id(self):
+        for good_value in ["job-aB3456789012345678901234",
+                           "localjob-1",
+                           None]:
+            dxjob = dxpy.DXJob(good_value)
+            dxjob.set_id(good_value)
+        for bad_value in ["foo",
+                          "project-123456789012345678901234",
+                          3,
+                          {},
+                          "job-aB34567890123456789012345",
+                          "job-aB345678901234567890123"]:
+            with self.assertRaises(DXError):
+                dxpy.DXJob(bad_value)
+            with self.assertRaises(DXError):
+                dxjob = dxpy.DXJob()
+                dxjob.set_id(bad_value)
+
     def test_run_dxapplet_and_job_metadata(self):
         dxapplet = dxpy.DXApplet()
         dxapplet.new(name="test_applet",
@@ -982,6 +1079,22 @@ class TestDXWorkflow(unittest.TestCase):
     def tearDown(self):
         tearDownTempProjects(self)
 
+    def test_dxanalysis_init_and_set_id(self):
+        for good_value in ["analysis-aB3456789012345678901234", None]:
+            dxanalysis = dxpy.DXAnalysis(good_value)
+            dxanalysis.set_id(good_value)
+        for bad_value in ["foo",
+                          "project-123456789012345678901234",
+                          3,
+                          {},
+                          "analysis-aB34567890123456789012345",
+                          "analysis-aB345678901234567890123"]:
+            with self.assertRaises(DXError):
+                dxpy.DXAnalysis(bad_value)
+            with self.assertRaises(DXError):
+                dxanalysis = dxpy.DXAnalysis()
+                dxanalysis.set_id(bad_value)
+
     @unittest.skipUnless(testutil.TEST_RUN_JOBS,
                          'skipping test that would run a job')
     def test_run_workflow_and_analysis_metadata(self):
@@ -1417,6 +1530,30 @@ class TestDXApp(unittest.TestCase):
     def tearDown(self):
         tearDownTempProjects(self)
 
+    def test_init_and_set_id(self):
+        for good_values in [("app-aB3456789012345678901234", None, None),
+                            (None, 'name', 'tag'),
+                            (None, 'name', None),
+                            (None, None, None)]:
+            dxapp = dxpy.DXApp(*good_values)
+            dxapp.set_id(*good_values)
+        for bad_values in [("foo", None, None),
+                           ("app-aB3456789012345678901234", 'name', None),
+                           ("app-aB3456789012345678901234", None, 'tag'),
+                           ("app-aB3456789012345678901234", 'name', 'tag'),
+                           ("project-123456789012345678901234", None, None),
+                           (3, None, None),
+                           ({}, None, None),
+                           ("app-aB34567890123456789012345", None, None),
+                           ("app-aB345678901234567890123", None, None),
+                           (None, 3, None),
+                           (None, 'name', {})]:
+            with self.assertRaises(DXError):
+                dxpy.DXApp(*bad_values)
+            with self.assertRaises(DXError):
+                dxapp = dxpy.DXApp()
+                dxapp.set_id(*bad_values)
+
     def test_create_app(self):
         dxapplet = dxpy.DXApplet()
         dxapplet.new(name="test_applet",
@@ -1480,9 +1617,10 @@ class TestDXApp(unittest.TestCase):
 
         self.assertEqual(appdesc.get("tags", []), [])
 
-        with self.assertRaises(AttributeError):
+        # ResourceNotFound will be thrown if the alias cannot be found
+        with self.assertRaises(DXAPIError):
             dxpy.DXApp(name="test_add_and_remove_tags_app", alias="moo").applet
-        with self.assertRaises(AttributeError):
+        with self.assertRaises(DXAPIError):
             dxpy.DXApp(name="test_add_and_remove_tags_app", alias="oink").applet
 
         dxapp.add_tags(["moo", "oink"])
@@ -1492,15 +1630,15 @@ class TestDXApp(unittest.TestCase):
 
         dxapp.remove_tags(["moo"])
 
-        with self.assertRaises(AttributeError):
+        with self.assertRaises(DXAPIError):
             dxpy.DXApp(name="test_add_and_remove_tags_app", alias="moo").applet
         self.assertEqual(dxapplet.get_id(), dxpy.DXApp(name="test_add_and_remove_tags_app", alias="oink").applet)
 
         dxapp.remove_tags(["oink"])
 
-        with self.assertRaises(AttributeError):
+        with self.assertRaises(DXAPIError):
             dxpy.DXApp(name="test_add_and_remove_tags_app", alias="moo").applet
-        with self.assertRaises(AttributeError):
+        with self.assertRaises(DXAPIError):
             dxpy.DXApp(name="test_add_and_remove_tags_app", alias="oink").applet
 
 
